@@ -160,7 +160,18 @@ class CloudFrontToMediaStore(
         :summary: Constructs a new instance of CloudFrontToMediaStore class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToMediaStore.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToMediaStoreProps(
@@ -243,7 +254,16 @@ class CloudFrontToMediaStoreProps:
         if isinstance(media_store_container_props, dict):
             media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontToMediaStoreProps.__init__)
+            def stub(
+                *,
+                cloud_front_distribution_props: typing.Any = None,
+                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+                insert_http_security_headers: typing.Optional[builtins.bool] = None,
+                media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
             check_type(argname="argument existing_media_store_container_obj", value=existing_media_store_container_obj, expected_type=type_hints["existing_media_store_container_obj"])
